@@ -23,6 +23,8 @@ import unittest
 
 from fedmsg.tests.test_meta import Base
 
+from common import add_doc
+
 
 class TestNewBadge(Base):
     """ These messages are published when `Open Badges
@@ -114,5 +116,38 @@ class TestRankAdvance(Base):
     }
 
 
+class TestFirstLogin(Base):
+    """ When a user logs in to the `Fedora Badges
+    <https://badges.fedoraproject.org>`_ site for the very first time, we
+    publish a message like this one.
+    """
+    expected_title = "fedbadges.person.login.first"
+    expected_subti = "ralph logged in to badges.fedoraproject.org " + \
+        "for the first time"
+    expected_link = "https://badges.fedoraproject.org/user/ralph"
+    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_packages = set([])
+    expected_usernames = set(['ralph'])
+    expected_objects = set([])
+    msg = {
+        "i": 2,
+        "msg": {
+            "user": {
+                "badges_user_id": 2,
+                "username": "ralph"
+            }
+        },
+        "msg_id": "2013-be88d409-cdd7-47f0-9edd-87088f8505d2",
+        "source_name": "datanommer",
+        "source_version": "0.6.0",
+        "timestamp": 1382804277.0,
+        "topic": "org.fedoraproject.prod.fedbadges.person.login.first"
+    }
+
+
+add_doc(locals())
+
 if __name__ == '__main__':
     unittest.main()
