@@ -200,7 +200,7 @@ class TestLegacyComposeRawhideComplete(Base):
     expected_title = "compose.rawhide.complete"
     expected_subti = "rawhide compose completed"
     expected_link = \
-        "http://kojipkgs.fedoraproject.org/mash/rawhide-20120808"
+        "https://dl.fedoraproject.org/pub/fedora/linux/development/rawhide"
     expected_objects = set(['rawhide/primary'])
     msg = {
         "i": 1,
@@ -302,7 +302,7 @@ class TestLegacyComposeRawhideRsyncComplete(Base):
     expected_title = "compose.rawhide.rsync.complete"
     expected_subti = "finished rsync of rawhide compose"
     expected_link = \
-        "http://kojipkgs.fedoraproject.org/mash/rawhide-20120808"
+        "https://dl.fedoraproject.org/pub/fedora/linux/development/rawhide"
     expected_objects = set(['rawhide/primary'])
     msg = {
         "i": 1,
@@ -543,7 +543,7 @@ class TestComposeRawhideComplete(Base):
     expected_subti = "rawhide compose completed"
     expected_objects = set(['rawhide/primary'])
     expected_link = \
-        "http://kojipkgs.fedoraproject.org/mash/rawhide-20120808"
+        "https://dl.fedoraproject.org/pub/fedora/linux/development/rawhide"
     msg = {
         "i": 1,
         "timestamp": 1344447839.891876,
@@ -659,7 +659,7 @@ class TestComposeRawhideRsyncComplete(Base):
     expected_title = "compose.rawhide.rsync.complete"
     expected_subti = "finished rsync of rawhide compose"
     expected_link = \
-        "http://kojipkgs.fedoraproject.org/mash/rawhide-20120808"
+        "https://dl.fedoraproject.org/pub/fedora/linux/development/rawhide"
     expected_objects = set(['rawhide/primary'])
     msg = {
         "i": 1,
