@@ -23,6 +23,8 @@ import unittest
 
 from fedmsg.tests.test_meta import Base
 
+from common import add_doc
+
 
 class TestTracTicketCreate(Base):
     """ Messages are published on this topic when a user opens a new ticket
@@ -31,9 +33,9 @@ class TestTracTicketCreate(Base):
 
     expected_title = "trac.ticket.new"
     expected_subti = "ralph opened a new ticket on the moksha trac instance"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph', 'lmacken'])
     expected_objects = set([
@@ -86,9 +88,9 @@ class TestTracTicketChange(Base):
 
     expected_title = "trac.ticket.update"
     expected_subti = "ralph updated a ticket on the moksha trac instance"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -145,9 +147,9 @@ class TestTracTicketChangeReopen(Base):
 
     expected_title = "trac.ticket.update"
     expected_subti = "ralph reopened a ticket on the moksha trac instance"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -206,11 +208,11 @@ class TestTracTicketChangeClosed(Base):
     """
 
     expected_title = "trac.ticket.update"
-    expected_subti = "ralph closed a ticket on the moksha trac " + \
-        "instance as 'wontfix'"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_subti = ("ralph closed a ticket on the moksha trac "
+                      "instance as 'wontfix'")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -269,11 +271,11 @@ class TestTracTicketDelete(Base):
     """
 
     expected_title = "trac.ticket.delete"
-    expected_subti = "ralph straight-up deleted a ticket on the moksha " +\
-        "trac instance"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_subti = ("ralph straight-up deleted a ticket on the moksha "
+                      "trac instance")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/" 
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -326,11 +328,11 @@ class TestTracWikiCreate(Base):
     """
 
     expected_title = "trac.wiki.page.new"
-    expected_subti = "ralph created a new 'watwat' wiki page on the " + \
-        "moksha trac instance"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_subti = ("ralph created a new 'watwat' wiki page on the "
+                      "moksha trac instance")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -372,18 +374,18 @@ class TestTracWikiEdit(Base):
     """
 
     expected_title = "trac.wiki.page.update"
-    expected_subti = "ralph updated the 'WikiStart' wiki page on the " + \
-        "moksha trac instance"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_subti = ("ralph updated the 'WikiStart' wiki page on the "
+                      "moksha trac instance")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
         'moksha/wiki/WikiStart',
     ])
-    expected_link = "https://fedorahosted.org/moksha/wiki/WikiStart" +\
-        "?action=diff&version=47"
+    expected_link = ("https://fedorahosted.org/moksha/wiki/WikiStart"
+                     "?action=diff&version=47")
 
     msg = {
         "username": "apache",
@@ -422,11 +424,11 @@ class TestTracWikiDelete(Base):
     on a `fedorahosted <http://fedorahosted.org>`_ trac instance.
     """
     expected_title = "trac.wiki.page.delete"
-    expected_subti = "ralph straight-up deleted the 'watwat' wiki page " + \
-        "on the moksha trac instance"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_subti = ("ralph straight-up deleted the 'watwat' wiki page "
+                      "on the moksha trac instance")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -469,18 +471,18 @@ class TestTracWikiVersionDelete(Base):
     """
 
     expected_title = "trac.wiki.page.version.delete"
-    expected_subti = "ralph deleted a version of the 'WikiStart' " + \
-        "wiki page on the moksha trac instance"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_subti = ("ralph deleted a version of the 'WikiStart' "
+                      "wiki page on the moksha trac instance")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
         'moksha/wiki/WikiStart',
     ])
-    expected_link = "https://fedorahosted.org/moksha/wiki/WikiStart" +\
-        "?action=diff&version=47"
+    expected_link = ("https://fedorahosted.org/moksha/wiki/WikiStart"
+                     "?action=diff&version=47")
 
     msg = {
         "username": "apache",
@@ -516,11 +518,11 @@ class TestTracWikiRename(Base):
     """
 
     expected_title = "trac.wiki.page.rename"
-    expected_subti = "ralph renamed the wiki page 'watwat' to 'watwat2' " + \
-        "on the moksha trac instance"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_subti = ("ralph renamed the wiki page 'watwat' to 'watwat2' "
+                      "on the moksha trac instance")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -567,18 +569,18 @@ class TestTracChangesetCreate(Base):
     """
 
     expected_title = "trac.git.receive"
-    expected_subti = "ralph pushed some commits to the 'moksha' " + \
-        "fedorahosted git repository"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_subti = ("ralph pushed some commits to the 'moksha' "
+                      "fedorahosted git repository")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
         'moksha/git/README.rst',
     ])
-    expected_link = "https://git.fedorahosted.org/cgit/moksha.git/" + \
-        "commit/?id=24bcd20d08a68320f82951ce20959bc6a1a6e79c"
+    expected_link = ("https://git.fedorahosted.org/cgit/moksha.git/"
+                     "commit/?id=24bcd20d08a68320f82951ce20959bc6a1a6e79c")
 
     msg = {
         "username": "ralph",
@@ -625,18 +627,18 @@ class TestTracDocsChangesetCreate(Base):
     """
 
     expected_title = "trac.git.receive"
-    expected_subti = "ralph pushed some commits to the " + \
-        "'docs/about-fedora' fedorahosted git repository"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_subti = ("ralph pushed some commits to the "
+                      "'docs/about-fedora' fedorahosted git repository")
+    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
+                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
         'docs/about-fedora/git/README.rst',
     ])
-    expected_link = "https://git.fedorahosted.org/cgit/docs/" + \
-        "about-fedora.git/commit/?id=24bcd20d08a68320f82951ce20959bc6a1a6e79c"
+    expected_link = ("https://git.fedorahosted.org/cgit/docs/"
+                     "about-fedora.git/commit/?id=24bcd20d08a68320f82951ce20959bc6a1a6e79c")
 
     msg = {
         "username": "ralph",
@@ -674,6 +676,7 @@ class TestTracDocsChangesetCreate(Base):
         }
     }
 
+add_doc(locals())
 
 if __name__ == '__main__':
     unittest.main()
